@@ -3,8 +3,7 @@ import sys
 import re
 import shutil
 import subprocess
-import pkg_resources
-
+import importlib.resources as resources
 
 def main():
     args = sys.argv[1:]
@@ -40,13 +39,11 @@ def to_pascal_case(input_string: str) -> str:
 
     return pascal_case
 
-
 def cpy(src, dest):
-    template_dir = pkg_resources.resource_filename("pam", "templates")
+    template_dir = resources.files("pam") / "templates"
     src_file = os.path.join(template_dir, src)
     shutil.copy(src_file, dest)
 
-
 def replace_template_content(service_name, class_name, file_name):
     file_path = os.path.join(service_name, file_name)
     with open(file_path, 'r+', encoding='utf-8') as file:
