@@ -18,7 +18,7 @@ class ITaskManager(ABC):
         pass
 
     @abstractmethod
-    def service_request_data(self, service: Service, page):
+    def service_request_data(self, service: Service, page, filter_contact_ids=None):
         pass
 
     @abstractmethod
@@ -30,7 +30,7 @@ class ITaskManager(ABC):
         pass
 
     @abstractmethod
-    def service_upload_result(self, service: Service, file_path):
+    def service_upload_result(self, service: Service, file_path, options=None):
         pass
 
     @abstractmethod
