@@ -2,7 +2,7 @@ from abc import abstractmethod
 from pathlib import Path
 from datetime import datetime
 import json
-from typing import TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, Union, Optional, List
 import pandas as pd
 import dask.dataframe as dd
 from pam.utils import log, deep_convert_numbers_to_strings, get_adapter_id
@@ -29,13 +29,17 @@ class Service:
         return get_adapter_id(self.request.response_api)
     
     # == REQUEST DATA ===
-    def _request_data(self, page: str = "") -> None:
+    def _request_data(self, page: str = "", filter_contact_ids: Optional[List[str]] = None) -> None:
         """Requests data for the specified page."""
         log(f"{self.request.service_name}: Requesting data for page={page}")
-        self.task_manager.service_request_data(self, page)
+        self.task_manager.service_request_data(self, page, filter_contact_ids)
 
     # == UPLOAD RESULT ===
-    def _upload_result(self, df: Union[pd.DataFrame, dd.DataFrame]) -> str:
+    def _upload_result(
+        self,
+        df: Union[pd.DataFrame, dd.DataFrame],
+        options: Optional[dict] = None,
+    ) -> str:
         """
         Uploads the result DataFrame to a temporary file and notifies the task manager.
         """
@@ -56,7 +60,7 @@ class Service:
         try:
             df.to_csv(tmp_file_name, index=False)
             log(f"{self.request.service_name}: Uploading result file: {tmp_file_name}")
-            self.task_manager.service_upload_result(self, tmp_file_name)
+            self.task_manager.service_upload_result(self, tmp_file_name, options)
         except Exception as e:
             log(f"Failed to upload result file: {e}")
             raise
